@@ -91,3 +91,38 @@ class CalibrateBase(abc.ABC):
             ds_out[key] = val
 
         return ds_out
+
+    def _check_echodata_backscatter_size(self):
+        """
+        Extracts total size of `backscatter_r` and `backscatter_i` in a beam group.
+        If the size is above 2 GiB, raises a warning showing a recommended workflow
+        that will not overwhelm the system memory.
+        """
+        # Initialize total nbytes
+        if self.echodata.sonar_model == "EK80":
+            # Select source of backscatter data
+            beam = self.echodata[self.ed_beam_group]
+
+            # Go through waveform and encode cases
+            if (self.waveform_mode == "BB") or (
+                self.waveform_mode == "CW" and self.encode_mode == "complex"
+            ):
+                total_nbytes = beam["backscatter_r"].nbytes + beam["backscatter_i"].nbytes
+            elif self.waveform_mode == "CW" and self.encode_mode == "power":
+                total_nbytes = beam["backscatter_r"].nbytes
+        else:
+            total_nbytes = self.echodata["Sonar/Beam_group1"]["backscatter_r"].nbytes
+
+        # Compute GigaBytes from Bytes
+        total_gb = total_nbytes / (1024**3)
+
+        # Raise Warning if above 2.0
+        if total_gb > 2.0:
+            logger.warning(
+                "The Echodata Backscatter Variables are large and can cause memory issues. "
+                "Consider modifying compute_Sv workflow: "
+                "Prior to `compute_Sv` run `echodata.chunk(CHUNK_DICTIONARY) "
+                "and after `compute_Sv` run `ds_Sv.to_zarr(ZARR_STORE, compute=True)`. "
+                "This will ensure that the computation is lazily evaluated, "
+                "with the results stored directly in a Zarr store on disk, rather then in memory."
+            )
