@@ -28,8 +28,6 @@ class CalibrateEK(CalibrateBase):
 
         self.ed_beam_group = None  # will be assigned in child class
 
-        self.ed_beam_group = None  # will be assigned in child class
-
     def compute_echo_range(self, chan_sel: xr.DataArray = None):
         """
         Compute echo range for EK echosounders.
@@ -128,7 +126,7 @@ class CalibrateEK(CalibrateBase):
 
         # Remove time1 if exist as a coordinate
         if "time1" in out.coords:
-            out = out.drop("time1")
+            out = out.drop_vars("time1")
 
         return out
 
@@ -322,7 +320,7 @@ class CalibrateEK80(CalibrateEK):
             # assume transmit_type identical for all pings in a channel
             first_ping_transmit_type = (
                 beam["transmit_type"].isel(ping_time=0).drop_vars("ping_time")
-            )  # noqa
+            ).compute()  # noqa
             return {
                 # For BB: Keep only non-CW channels (LFM or FMD) based on transmit_type
                 "BB": first_ping_transmit_type.where(
@@ -544,9 +542,9 @@ class CalibrateEK80(CalibrateEK):
                 ping_time=beam["ping_time"],
             )
             # Use pulse_duration in place of tau_effective for GPT channels
-            # below assumesthat all transmit parameters are identical
+            # TODO: below assumes that all transmit parameters are identical
             # and needs to be changed when allowing transmit parameters to vary by ping
-            ch_GPT = vend["transceiver_type"] == "GPT"
+            ch_GPT = (vend["transceiver_type"] == "GPT").compute()
             tau_effective[ch_GPT] = beam["transmit_duration_nominal"][ch_GPT].isel(ping_time=0)
 
             # equivalent_beam_angle
