@@ -32,9 +32,12 @@ def compute_MVBS(
     range_var: Literal["echo_range", "depth"] = "echo_range",
     range_bin: str = "20m",
     ping_time_bin: str = "20s",
-    method="map-reduce",
-    skipna=True,
+    method: str = "map-reduce",
+    reindex: bool = False,
+    skipna: bool = True,
+    fill_value: float = np.nan,
     closed: Literal["left", "right"] = "left",
+    range_var_max: str = None,
     **flox_kwargs,
 ):
     """
@@ -63,11 +66,23 @@ def compute_MVBS(
         The flox strategy for reduction of dask arrays only.
         See flox `documentation <https://flox.readthedocs.io/en/latest/implementation.html>`_
         for more details.
+    reindex: bool, default False
+        If False, reindex after the blockwise stage. If True, reindex at the blockwise stage.
+        Generally, `reindex=False` results in less memory at the cost of computation speed.
+        Can only be used when method='map-reduce'.
+        See flox `documentation <https://flox.readthedocs.io/en/latest/implementation.html>`_
+        for more details.
     skipna: bool, default True
         If true, the mean operation skips NaN values.
         Else, the mean operation includes NaN values.
+    fill_value: float, default np.nan
+        Fill value when no group data exists to aggregate.
     closed: {'left', 'right'}, default 'left'
         Which side of bin interval is closed.
+    range_var_max: str, default None
+        Range variable maximum. Can be true range variable maximum or the maximum depth the
+        user wishes to regrid to. If known, users can pass in range variable maximum to
+        ensure that `compute_MVBS` can lazily run without any computation.
     **flox_kwargs
         Additional keyword arguments to be passed
         to flox reduction function.
@@ -76,6 +91,8 @@ def compute_MVBS(
     -------
     A dataset containing bin-averaged Sv
     """
+    if method != "map-reduce" and reindex is not None:
+        raise ValueError(f"Passing in reindex={reindex} is only allowed when method='map_reduce'.")
 
     # Setup and validate
     # * Sv dataset must contain specified range_var
@@ -86,10 +103,15 @@ def compute_MVBS(
     if not isinstance(ping_time_bin, str):
         raise TypeError("ping_time_bin must be a string")
 
-    # create bin information for echo_range
-    # this computes the echo range max since there might NaNs in the data
-    echo_range_max = ds_Sv[range_var].max()
-    range_interval = np.arange(0, echo_range_max + range_bin, range_bin)
+    # Create bin information for the range variable
+    if range_var_max is None:
+        # This computes the range variable max since there might be NaNs in the data
+        range_var_max = ds_Sv[range_var].max(skipna=True)
+    else:
+        # Parse string and small increase to ensure that we get the bin
+        # corresponding to range_var_max
+        range_var_max = _parse_x_bin(range_var_max) + 1e-8
+    range_interval = np.arange(0, range_var_max + range_bin, range_bin)
 
     # create bin information needed for ping_time
     d_index = (
@@ -109,7 +131,9 @@ def compute_MVBS(
         ping_interval,
         range_var=range_var,
         method=method,
+        reindex=reindex,
         skipna=skipna,
+        fill_value=fill_value,
         **flox_kwargs,
     )
 
@@ -175,10 +199,6 @@ def compute_MVBS(
             "binning_mode": "physical units",
             "range_meter_interval": str(range_bin) + "m",
             "ping_time_interval": ping_time_bin,
-            "actual_range": [
-                round(float(ds_MVBS["Sv"].min().values), 2),
-                round(float(ds_MVBS["Sv"].max().values), 2),
-            ],
         }
     )
 
@@ -279,6 +299,7 @@ def compute_NASC(
 ) -> xr.Dataset:
     """
     Compute Nautical Areal Scattering Coefficient (NASC) from an Sv dataset.
+    TODO: Add range_var_max and reindex parameters to match `compute_MVBS`.
 
     Parameters
     ----------
