@@ -31,11 +31,21 @@ SV_OFFSET = {
         500: 1.1,
         **SV_OFFSET_HF,
     },
+    120000.0: {
+        150: 1.4,
+        250: 1.3,
+        **SV_OFFSET_HF,
+    },
     125000.0: {
         150: 1.4,
         250: 1.3,
         **SV_OFFSET_HF,
     },
+    130000.0: {
+        150: 1.4,
+        250: 1.3,
+        **SV_OFFSET_HF,
+    },
     200000.0: {
         150: 1.4,
         250: 1.3,
@@ -111,7 +121,14 @@ class ParseAZFP(ParseBase):
     HEADER_FORMAT = ">HHHHIHHHHHHHHHHHHHHHHHHHHHHHHHHHHHBBBBHBBBBBBBBHHHHHHHHHHHHHHHHHHHH"
     FILE_TYPE = 64770
 
-    def __init__(self, file, file_meta, storage_options={}, dgram_zarr_vars={}, sonar_model="AZFP"):
+    def __init__(
+        self,
+        file,
+        file_meta,
+        storage_options={},
+        sonar_model="AZFP",
+        **kwargs,
+    ):
         super().__init__(file, storage_options, sonar_model)
         # Parent class attributes
         #  regex pattern used to grab datetime embedded in filename
