@@ -72,6 +72,13 @@ class SetGroupsEK60(SetGroupsBase):
         # In some examples the channels may not be ordered, thus sorting is required
         self.sorted_channel = dict(sorted(channel_ids.items(), key=lambda item: item[1]))
 
+        # Select channels where parser `power` is not empty
+        self.sorted_channel = {
+            key: value
+            for key, value in self.sorted_channel.items()
+            if len(self.parser_obj.ping_data_dict["power"][key]) != 0
+        }
+
         # obtain corresponding frequency dict from sorted channels
         self.freq = [
             self.parser_obj.config_datagram["transceivers"][ch]["frequency"]
@@ -310,6 +317,18 @@ class SetGroupsEK60(SetGroupsBase):
         ds = xr.merge([ds, ds_plat], combine_attrs="override")
         ds = ds.assign_attrs(platform_dict)
 
+        # If `.IDX` file exists and `.IDX` data is parsed
+        if (
+            (self.parser_obj.idx_file != "")
+            and self.parser_obj.idx["ping_number"]
+            and self.parser_obj.idx["file_offset"]
+            and self.parser_obj.idx["vessel_distance"]
+            and self.parser_obj.idx["latitude"]
+            and self.parser_obj.idx["longitude"]
+            and self.parser_obj.idx["timestamp"]
+        ):
+            ds = self._add_index_data_to_platform_ds(ds)
+
         return set_time_encodings(ds)
 
     def set_beam(self) -> List[xr.Dataset]:
@@ -748,4 +767,13 @@ class SetGroupsEK60(SetGroupsBase):
                 ),
             },
         )
+
+        # If `.BOT` file exists and `.BOT` data is parsed
+        if (
+            (self.parser_obj.bot_file != "")
+            and self.parser_obj.bot["depth"]
+            and self.parser_obj.bot["timestamp"]
+        ):
+            ds = self._add_seafloor_detection_data_to_vendor_ds(ds)
+
         return ds
