@@ -8,6 +8,7 @@ from numpy.typing import NDArray
 from ..utils.coding import set_time_encodings
 from ..utils.log import _init_logger
 from .set_groups_base import SetGroupsBase
+from .utils.ek_duplicates import check_unique_ping_time_duplicates
 
 logger = _init_logger(__name__)
 
@@ -173,7 +174,7 @@ class SetGroupsEK80(SetGroupsBase):
                     (
                         self.parser_obj.environment["sound_velocity_profile"][::2]
                         if "sound_velocity_profile" in self.parser_obj.environment
-                        else []
+                        else [np.nan]
                     ),
                     {
                         "standard_name": "depth",
@@ -227,7 +228,7 @@ class SetGroupsEK80(SetGroupsBase):
         # Create dataset
         sonar_vars = {
             "frequency_nominal": (
-                ["channel"],
+                ["channel_all"],
                 var["transducer_frequency"],
                 {
                     "units": "Hz",
@@ -237,21 +238,21 @@ class SetGroupsEK80(SetGroupsBase):
                 },
             ),
             "transceiver_serial_number": (
-                ["channel"],
+                ["channel_all"],
                 var["serial_number"],
                 {
                     "long_name": "Transceiver serial number",
                 },
             ),
             "transducer_name": (
-                ["channel"],
+                ["channel_all"],
                 var["transducer_name"],
                 {
                     "long_name": "Transducer name",
                 },
             ),
             "transducer_serial_number": (
-                ["channel"],
+                ["channel_all"],
                 var["transducer_serial_number"],
                 {
                     "long_name": "Transducer serial number",
@@ -261,8 +262,8 @@ class SetGroupsEK80(SetGroupsBase):
         ds = xr.Dataset(
             {**sonar_vars, **beam_groups_vars},
             coords={
-                "channel": (
-                    ["channel"],
+                "channel_all": (
+                    ["channel_all"],
                     self.sorted_channel["all"],
                     self._varattrs["beam_coord_default"]["channel"],
                 ),
@@ -303,20 +304,47 @@ class SetGroupsEK80(SetGroupsBase):
             water_level = np.nan
             logger.info("WARNING: The water_level_draft was not in the file. Value set to NaN.")
 
-        time1, msg_type, lat, lon = self._extract_NMEA_latlon()
-        time2 = self.parser_obj.mru.get("timestamp", None)
+        time1, msg_type, lat_nmea, lon_nmea = self._extract_NMEA_latlon()
+        time2 = self.parser_obj.mru0.get("timestamp", None)
         time2 = np.array(time2) if time2 is not None else [np.nan]
+        time3 = self.parser_obj.mru1.get("timestamp", None)
+        time3 = np.array(time3) if time3 is not None else [np.nan]
 
-        # Handle potential nan timestamp for time1 and time2
+        # Handle potential nan timestamp for time1, time2, and time3
         time1 = self._nan_timestamp_handler(time1)
         time2 = self._nan_timestamp_handler(time2)
+        time3 = self._nan_timestamp_handler(time3)
+
+        # Set MRU1 lat lon attributes
+        latitude_mru1_attrs = self._varattrs["platform_var_default"]["latitude"].copy()
+        latitude_mru1_attrs.update(
+            {
+                "comment": "Derived from the Simrad MRU1 Datagrams which are "
+                "a wrapper of the Kongsberg Maritime Binary Datagrams."
+            }
+        )
+        longitude_mru1_attrs = self._varattrs["platform_var_default"]["longitude"].copy()
+        longitude_mru1_attrs.update(
+            {
+                "comment": "Derived from the Simrad MRU1 Datagrams which are "
+                "a wrapper of the Kongsberg Maritime Binary Datagrams."
+            }
+        ),
 
         # Assemble variables into a dataset: variables filled with nan if do not exist
         platform_dict = {"platform_name": "", "platform_type": "", "platform_code_ICES": ""}
         ds = xr.Dataset(
             {
-                "latitude": (["time1"], lat, self._varattrs["platform_var_default"]["latitude"]),
-                "longitude": (["time1"], lon, self._varattrs["platform_var_default"]["longitude"]),
+                "latitude": (
+                    ["time1"],
+                    lat_nmea,
+                    self._varattrs["platform_var_default"]["latitude"],
+                ),
+                "longitude": (
+                    ["time1"],
+                    lon_nmea,
+                    self._varattrs["platform_var_default"]["longitude"],
+                ),
                 "sentence_type": (
                     ["time1"],
                     msg_type,
@@ -324,17 +352,17 @@ class SetGroupsEK80(SetGroupsBase):
                 ),
                 "pitch": (
                     ["time2"],
-                    np.array(self.parser_obj.mru.get("pitch", [np.nan])),
+                    np.array(self.parser_obj.mru0.get("pitch", [np.nan])),
                     self._varattrs["platform_var_default"]["pitch"],
                 ),
                 "roll": (
                     ["time2"],
-                    np.array(self.parser_obj.mru.get("roll", [np.nan])),
+                    np.array(self.parser_obj.mru0.get("roll", [np.nan])),
                     self._varattrs["platform_var_default"]["roll"],
                 ),
                 "vertical_offset": (
                     ["time2"],
-                    np.array(self.parser_obj.mru.get("heave", [np.nan])),
+                    np.array(self.parser_obj.mru0.get("heave", [np.nan])),
                     self._varattrs["platform_var_default"]["vertical_offset"],
                 ),
                 "water_level": (
@@ -410,7 +438,7 @@ class SetGroupsEK80(SetGroupsBase):
                 ),
                 "heading": (
                     ["time2"],
-                    np.array(self.parser_obj.mru.get("heading", [np.nan])),
+                    np.array(self.parser_obj.mru0.get("heading", [np.nan])),
                     {
                         "long_name": "Platform heading (true)",
                         "standard_name": "platform_orientation",
@@ -419,6 +447,16 @@ class SetGroupsEK80(SetGroupsBase):
                         "valid_max": 360.0,
                     },
                 ),
+                "latitude_mru1": (
+                    ["time3"],
+                    np.array(self.parser_obj.mru1.get("latitude", [np.nan])),
+                    latitude_mru1_attrs,
+                ),
+                "longitude_mru1": (
+                    ["time3"],
+                    np.array(self.parser_obj.mru1.get("longitude", [np.nan])),
+                    longitude_mru1_attrs,
+                ),
             },
             coords={
                 "channel": (
@@ -445,9 +483,34 @@ class SetGroupsEK80(SetGroupsBase):
                         "orientation data.",
                     },
                 ),
+                "time3": (
+                    ["time3"],
+                    time3,
+                    {
+                        "axis": "T",
+                        "long_name": "Timestamps for platform motion and orientation data "
+                        "from the Kongsberg Maritime Binary Datagram",
+                        "standard_name": "time",
+                        "comment": "Time coordinate corresponding to platform motion and "
+                        "orientation data from the Kongsberg Maritime Binary Datagram.",
+                    },
+                ),
             },
         )
         ds = ds.assign_attrs(platform_dict)
+
+        # If `.IDX` file exists and `.IDX` data is parsed
+        if (
+            (self.parser_obj.idx_file != "")
+            and self.parser_obj.idx["ping_number"]
+            and self.parser_obj.idx["file_offset"]
+            and self.parser_obj.idx["vessel_distance"]
+            and self.parser_obj.idx["latitude"]
+            and self.parser_obj.idx["longitude"]
+            and self.parser_obj.idx["timestamp"]
+        ):
+            ds = self._add_index_data_to_platform_ds(ds)
+
         return set_time_encodings(ds)
 
     def _assemble_ds_ping_invariant(self, params, data_type):
@@ -1083,6 +1146,17 @@ class SetGroupsEK80(SetGroupsBase):
 
             ds_data = self._attach_vars_to_ds_data(ds_data, ch, rs_size=ds_data.range_sample.size)
 
+            # Access the 'ping_time' coordinate as a NumPy array
+            ping_times = ds_data["ping_time"].values
+
+            # Check if ping time duplicates exist
+            if len(ping_times) > len(np.unique(ping_times)):
+                # Check for unique ping time duplicates and if they are not unique, raise warning.
+                check_unique_ping_time_duplicates(ds_data, logger)
+
+                # Drop duplicates
+                ds_data = ds_data.drop_duplicates(dim="ping_time")
+
             if ch in self.sorted_channel["complex"]:
                 ds_complex.append(ds_data)
             else:
@@ -1286,17 +1360,18 @@ class SetGroupsEK80(SetGroupsBase):
             fil_coeffs = self.parser_obj.fil_coeffs.get(ch, None)
             fil_df = self.parser_obj.fil_df.get(ch, None)
 
-            if fil_coeffs and fil_df:
+            for type_num in param_map.keys():
+                param = param_map[type_num]
+
                 # get filter coefficient values
-                for type_num, values in fil_coeffs.items():
-                    param = param_map[type_num]
-                    coeffs_and_decimation[param][FILTER_IMAG].append(np.imag(values))
-                    coeffs_and_decimation[param][FILTER_REAL].append(np.real(values))
+                val_imag = np.imag(fil_coeffs[type_num]) if fil_coeffs else [np.nan]
+                val_real = np.real(fil_coeffs[type_num]) if fil_coeffs else [np.nan]
+                coeffs_and_decimation[param][FILTER_IMAG].append(val_imag)
+                coeffs_and_decimation[param][FILTER_REAL].append(val_real)
 
                 # get decimation factor values
-                for type_num, value in fil_df.items():
-                    param = param_map[type_num]
-                    coeffs_and_decimation[param][DECIMATION].append(value)
+                val_deci = fil_df[type_num] if fil_df else np.nan
+                coeffs_and_decimation[param][DECIMATION].append(val_deci)
 
         # Assemble everything into a Dataset
         ds = xr.merge([ds_table, ds_cal])
@@ -1307,6 +1382,14 @@ class SetGroupsEK80(SetGroupsBase):
         # Save the entire config XML in vendor group in case of info loss
         ds["config_xml"] = self.parser_obj.config_datagram["xml"]
 
+        # If `.BOT` file exists and `.BOT` data is parsed
+        if (
+            (self.parser_obj.bot_file != "")
+            and self.parser_obj.bot["depth"]
+            and self.parser_obj.bot["timestamp"]
+        ):
+            ds = self._add_seafloor_detection_data_to_vendor_ds(ds)
+
         return ds
 
     @staticmethod
