@@ -9,7 +9,7 @@ import fsspec
 import numpy as np
 import pandas as pd
 import xarray as xr
-from datatree import DataTree
+from xarray import DataTree
 
 from ..utils.io import validate_output_path
 from ..utils.log import _init_logger
@@ -18,7 +18,7 @@ from .echodata import EchoData
 
 logger = _init_logger(__name__)
 
-POSSIBLE_TIME_DIMS = {"time1", "time2", "time3", "ping_time"}
+POSSIBLE_TIME_DIMS = {"time1", "time2", "time3", "time4", "nmea_time", "ping_time"}
 APPEND_DIMS = {"filenames"}.union(POSSIBLE_TIME_DIMS)
 DATE_CREATED_ATTR = "date_created"
 CONVERSION_TIME_ATTR = "conversion_time"
@@ -102,7 +102,7 @@ def check_zarr_path(
 
 
 def _check_channel_selection_form(
-    channel_selection: Optional[Union[List, Dict[str, list]]] = None
+    channel_selection: Optional[Union[List, Dict[str, list]]] = None,
 ) -> None:
     """
     Ensures that the provided user input ``channel_selection`` is in
@@ -133,7 +133,7 @@ def _check_channel_selection_form(
 
         # make sure all keys are of the form Sonar/Beam_group using regular expression
         are_keys_right_form = [
-            True if re.match("Sonar/Beam_group(\d{1})", elem) else False  # noqa
+            True if re.match(r"Sonar/Beam_group(\d{1})", elem) else False  # noqa
             for elem in channel_selection.keys()
         ]
         if not all(are_keys_right_form):
